#
# spec file for package python-xhtml2pdf
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-xhtml2pdf
Version:        0.2.6
Release:        1.9
Summary:        PDF Generator Using HTML and CSS
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/xhtml2pdf/xhtml2pdf
Source:         https://github.com/xhtml2pdf/xhtml2pdf/archive/refs/tags/v%{version}.tar.gz#/xhtml2pdf-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pillow >= 7.0.2
Requires:       python-PyPDF3 >= 1.0.5
Requires:       python-arabic-reshaper >= 2.1.0
Requires:       python-html5lib >= 1.0
Requires:       python-python-bidi >= 0.4.2
Requires:       python-reportlab >= 3.0
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
Conflicts:      python-pisa
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Pillow >= 7.0.2}
BuildRequires:  %{python_module PyPDF3 >= 1.0.5}
BuildRequires:  %{python_module arabic-reshaper >= 2.1.0}
BuildRequires:  %{python_module html5lib >= 1.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-bidi >= 0.4.2}
BuildRequires:  %{python_module reportlab >= 3.0}
# /SECTION
%python_subpackages

%description
xhtml2pdf is a html2pdf converter using the ReportLab Toolkit, the HTML5lib and
pyPdf. It supports HTML 5 and CSS 2.1 (and some of CSS 3). It is completely
written in pure Python so it is platform independent.

The main benefit of this tool that a user with Web skills like HTML and CSS is
able to generate PDF templates very quickly without learning new technologies.

%prep
%setup -q -n xhtml2pdf-%{version}
%autopatch -p1

sed -i '1{/^#!/d}' xhtml2pdf/paragraph.py xhtml2pdf/w3c/*.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/xhtml2pdf
%python_clone -a %{buildroot}%{_bindir}/pisa
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative xhtml2pdf
%python_install_alternative pisa

%postun
%python_uninstall_alternative xhtml2pdf
%python_uninstall_alternative pisa

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/*
%python_alternative %{_bindir}/pisa
%python_alternative %{_bindir}/xhtml2pdf

%changelog
* Fri Oct 14 2022 pgajdos@suse.com
- version update to 0.2.6
  * Drop python 2 support.
  * Remove most of python 2 code and cleanup
  * Update packages dependencies
  * Remove six dependency and update Readme
  * Set timeout in https options
  * Add new file manager approach using factory method, now new classes deal with different types of data
  * B64InlineURI, LocalProtocolURI, NetworkFileUri, LocalFileURI, BytesFileUri
  * Now getColor return None when None is passed ignoring default value, but return default if bool(data) == false
  * rtl languages reversed lines added as a ParaFrag (note: not fully supported yet)
  * Check if Paragraph has 'rtl' attribute (note: not fully supported yet)
  * Fix UnboundLocalError in reportlab_paragraph (#585) (#586)
  * Remove usage of getStringIO (#590) removed form reportlab
  * Change test for github workflow using only Linux
  * Add Python 3.9, 3.10
  * Switch from PyPDF2 to PyPDF3
  * Add SVG support
  * Update package information.
  * Allow call tests using make.
- deleted patches
  - 590-rm-getStringIO.patch (upstreamed)
* Sat Apr  9 2022 Matej Cepl <mcepl@suse.com>
- Add 590-rm-getStringIO.patch, use standard StringIO
  (gh#xhtml2pdf/xhtml2pdf#589).
* Sun Feb  7 2021 John Vandenberg <jayvdb@gmail.com>
- Add missing runtime dependency on setuptools
- Remove hashbang from library modules
- Activate test suite
- Update to v0.2.5
  * Added Asian fonts support (Simplified Chinese,
    Traditional Chinese, Japanese & Korean)
  * Added support for right-to-left writings like Arabic, Hebrew,
    Persian, Pashto, Urdu and Sindhi. Simply include for example
    <pdf:language name="arabic"/>
  * CSS property letter-spacing now supports float values and
    relative & absolute units like cm, in, em, %% etc
  * Added unit tests for Asian and right-to-left fonts
  * @frame properties like width, right, bottom etc. are now
    correctly calculated depending on the page orientation and size
  * Fixed support for multiple fonts and unicode
  * Fixed an encoding issue with html5lib
  * Fixed a problem with the border property in h1 to h6 heading tags
  * Fixed compability with ReportLab 3.5.X
  * Removed default background-image when no background-image is defined
  * Fixed an issue with different font type that have the same name
  * Fixed a bug that prevented support for Python 3.X
  * testrender test: fixed transparences and included new reference
    files. now all tests pass in Travis CI without --failed
  * 0.0 as value for a CSS property now acts the same way as 0 and None
  * Removed i and inch as unofficial synonyms for the in unit
* Fri May 15 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Feb  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.2.4
  * add Python 3.8
  * Fixed padding problem
  * fix: use html.escape instead of cgi.escape
  * Removed `if cols_with_no_width` condition from `tables.py`.
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.3:
  * various fixes/etc
  * no upstream changelog provided
* Fri Dec 15 2017 tchvatal@suse.com
- Switch to downloadable url
- Remove pointless patch
* Fri Dec 15 2017 tchvatal@suse.com
- Cleanup a bit
- Update the requirements to match the upstream recommendations
- Run the tests
- Really enable the python3
* Thu Dec 14 2017 opensuse@dstoecker.de
- update to 0.2b
- support build for python3
* Fri Aug 12 2016 opensuse@dstoecker.de
- update to 0.1b2
* Fri Nov 15 2013 p.drouand@gmail.com
- Update to version 0.0.5
  + no changelog available
- Remove useless CFLAGS definition
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Dec 12 2012 jfunk@funktronics.ca
- Initial release
